select distinct owner
from   all_db_links
order by owner
